@@ -1,14 +1,14 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """
-This file contains pytest configuration settings that are astropy-specific
-(i.e.  those that would not necessarily be shared by affiliated packages
-making use of astropy's test runner).
+This file contains pytest configuration settings that are astropy-specific.
 """
+
 import builtins
 import os
 import sys
 import tempfile
 import warnings
+from pathlib import Path
 
 try:
     from pytest_astropy_header.display import PYTEST_HEADER_MODULES, TESTED_VERSIONS
@@ -19,28 +19,10 @@ except ImportError:
 import pytest
 
 from astropy import __version__
-from astropy.utils.compat.numpycompat import NUMPY_LT_2_0
-
-if not NUMPY_LT_2_0:
-    import numpy as np
-
-    np.set_printoptions(legacy="1.25")
-
-# This is needed to silence a warning from matplotlib caused by
-# PyInstaller's matplotlib runtime hook.  This can be removed once the
-# issue is fixed upstream in PyInstaller, and only impacts us when running
-# the tests from a PyInstaller bundle.
-# See https://github.com/astropy/astropy/issues/10785
-if getattr(sys, "frozen", False) and hasattr(sys, "_MEIPASS"):
-    # The above checks whether we are running in a PyInstaller bundle.
-    warnings.filterwarnings("ignore", "(?s).*MATPLOTLIBDATA.*", category=UserWarning)
-
-# Note: while the filterwarnings is required, this import has to come after the
-# filterwarnings above, because this attempts to import matplotlib:
 from astropy.utils.compat.optional_deps import HAS_MATPLOTLIB
 
 if HAS_MATPLOTLIB:
-    import matplotlib
+    import matplotlib as mpl
 
 matplotlibrc_cache = {}
 
@@ -68,9 +50,15 @@ def fast_thread_switching():
 
 
 def pytest_configure(config):
-    from astropy.utils.iers import conf as iers_conf
+    # Ensure number of columns and lines is deterministic for testing
+    from astropy import conf
+
+    conf.max_width = 80
+    conf.max_lines = 24
 
     # Disable IERS auto download for testing
+    from astropy.utils.iers import conf as iers_conf
+
     iers_conf.auto_download = False
 
     builtins._pytest_running = True
@@ -78,9 +66,9 @@ def pytest_configure(config):
     if HAS_MATPLOTLIB:
         with warnings.catch_warnings():
             warnings.simplefilter("ignore")
-            matplotlibrc_cache.update(matplotlib.rcParams)
-            matplotlib.rcdefaults()
-            matplotlib.use("Agg")
+            matplotlibrc_cache.update(mpl.rcParams)
+            mpl.rcdefaults()
+            mpl.use("Agg")
 
     # Make sure we use temporary directories for the config and cache
     # so that the tests are insensitive to local configuration. Note that this
@@ -93,8 +81,8 @@ def pytest_configure(config):
     os.environ["XDG_CONFIG_HOME"] = tempfile.mkdtemp("astropy_config")
     os.environ["XDG_CACHE_HOME"] = tempfile.mkdtemp("astropy_cache")
 
-    os.mkdir(os.path.join(os.environ["XDG_CONFIG_HOME"], "astropy"))
-    os.mkdir(os.path.join(os.environ["XDG_CACHE_HOME"], "astropy"))
+    Path(os.environ["XDG_CONFIG_HOME"]).joinpath("astropy").mkdir()
+    Path(os.environ["XDG_CACHE_HOME"]).joinpath("astropy").mkdir()
 
     config.option.astropy_header = True
     PYTEST_HEADER_MODULES["PyERFA"] = "erfa"
@@ -120,9 +108,15 @@ def pytest_configure(config):
 
 
 def pytest_unconfigure(config):
-    from astropy.utils.iers import conf as iers_conf
+    # Undo settings related to number of lines/columns to show
+    from astropy import conf
+
+    conf.reset("max_width")
+    conf.reset("max_lines")
 
     # Undo IERS auto download setting for testing
+    from astropy.utils.iers import conf as iers_conf
+
     iers_conf.reset("auto_download")
 
     builtins._pytest_running = False
@@ -130,7 +124,7 @@ def pytest_unconfigure(config):
     if HAS_MATPLOTLIB:
         with warnings.catch_warnings():
             warnings.simplefilter("ignore")
-            matplotlib.rcParams.update(matplotlibrc_cache)
+            mpl.rcParams.update(matplotlibrc_cache)
             matplotlibrc_cache.clear()
 
     if builtins._xdg_config_home_orig is None:
@@ -147,7 +141,8 @@ def pytest_unconfigure(config):
 def pytest_terminal_summary(terminalreporter):
     """Output a warning to IPython users in case any tests failed."""
     try:
-        get_ipython()
+        # this name is only defined if running within ipython/jupyter
+        __IPYTHON__  # noqa: B018
     except NameError:
         return
 
