@@ -1,9 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Cosmological units and equivalencies."""
 
-from __future__ import annotations
-
-from astropy.units.utils import generate_unit_summary as _generate_unit_summary
+from astropy.units.docgen import generate_unit_summary as _generate_unit_summary
 
 __all__ = [
     # redshift equivalencies
