@@ -6,17 +6,16 @@ This module provides functionality to read CSV files into Astropy Tables using P
 import datetime
 import io
 import os
-from contextlib import ExitStack
 from typing import TYPE_CHECKING, BinaryIO, Literal, Union
 
 import numpy as np
-import numpy.typing
+from numpy.typing import DTypeLike, NDArray
 
 from astropy.utils.compat.optional_deps import HAS_PYARROW
+from astropy.utils.data import get_readable_fileobj
 
 if TYPE_CHECKING:
-    import numpy.typing as npt
-    import pyarrow as pa
+    import pyarrow
     import pyarrow.csv
 
     from astropy.table import Table
@@ -35,7 +34,7 @@ def read_csv(
     data_start: int | None = None,
     names: list[str] | None = None,
     include_names: list[str] | None = None,
-    dtypes: dict[str, numpy.typing.DTypeLike] | None = None,
+    dtypes: dict[str, DTypeLike] | None = None,
     comment: str | None = None,
     null_values: list[str] | None = None,
     encoding: str = "utf-8",
@@ -160,15 +159,14 @@ def read_csv(
         include_names, dtypes, null_values, timestamp_parsers
     )
 
-    table_pa = csv.read_csv(
-        input_file,
-        parse_options=parse_options,
-        read_options=read_options,
-        convert_options=convert_options,
-    )
-    table_apt = convert_pa_table_to_astropy_table(table_pa)
-
-    return table_apt
+    with get_readable_fileobj(input_file, encoding="binary") as f:
+        table_pa = csv.read_csv(
+            f,
+            parse_options=parse_options,
+            read_options=read_options,
+            convert_options=convert_options,
+        )
+    return convert_pa_table_to_astropy_table(table_pa)
 
 
 def check_has_pyarrow():
@@ -185,9 +183,7 @@ def check_has_pyarrow():
         )
 
 
-def convert_pa_string_array_to_numpy(
-    arr: "pa.Array",
-) -> "npt.NDArray":
+def convert_pa_string_array_to_numpy(arr: "pyarrow.Array") -> NDArray:
     """
     Convert a PyArrow string array to a NumPy array.
 
@@ -214,7 +210,7 @@ def convert_pa_string_array_to_numpy(
     return out
 
 
-def pyarrow_zero(data_type: "pa.DataType"):
+def pyarrow_zero(data_type: "pyarrow.DataType"):
     """
     Return a "zero" value for the given PyArrow data type.
 
@@ -275,8 +271,8 @@ def pyarrow_zero(data_type: "pa.DataType"):
 
 
 def convert_pa_array_to_numpy(
-    arr: Union["pa.Array", "pa.ChunkedArray"],
-) -> "npt.NDArray":
+    arr: Union["pyarrow.Array", "pyarrow.ChunkedArray"],
+) -> NDArray:
     """
     Convert a PyArrow array to a NumPy array.
 
@@ -339,8 +335,7 @@ def convert_pa_table_to_astropy_table(table_pa) -> "Table":
         name: convert_pa_array_to_numpy(col)
         for name, col in zip(table_pa.column_names, table_pa.itercolumns())
     }
-    out = Table(columns, copy=False)
-    return out
+    return Table(columns, copy=False)
 
 
 def strip_comment_lines(
@@ -394,29 +389,26 @@ def strip_comment_lines(
     """
     comment_encode = comment.encode(encoding)
 
-    with ExitStack() as stack:
-        if isinstance(input_file, (str, os.PathLike)):
-            input_file = stack.enter_context(open(input_file, "rb"))
-
+    with get_readable_fileobj(input_file, encoding="binary") as f:
         if header_start in (None, 0) and data_start is None:
             idx_last_comment = -1
-            for idx, line in enumerate(input_file):
+            for idx, line in enumerate(f):
                 if line.lstrip().startswith(comment_encode):
                     if idx - idx_last_comment == 1:
                         idx_last_comment = idx
                     else:
                         # Gap between comment lines, need to reset input file handle and
                         # break out to the logic below.
-                        input_file.seek(0)
+                        f.seek(0)
                         break
             else:
-                input_file.seek(0)
+                f.seek(0)
                 return None, idx_last_comment + 1
 
         # If we get here, we need to read the whole file and remove comment lines and
         # write into an output BytesIO file.
         output = io.BytesIO()
-        for idx, line in enumerate(input_file):
+        for idx, line in enumerate(f):
             if not line.lstrip().startswith(comment_encode):
                 output.write(line)
 
@@ -428,7 +420,7 @@ def strip_comment_lines(
 
 def get_convert_options(
     include_names: list[str] | None,
-    dtypes: dict[str, "npt.DTypeLike"] | None,
+    dtypes: dict[str, DTypeLike] | None,
     null_values: list[str] | None,
     timestamp_parsers: list[str] | None,
 ) -> "pyarrow.csv.ConvertOptions":
