@@ -10,6 +10,7 @@ Test :mod:`astropy.io.registry`.
 """
 
 import os
+import sys
 from collections import Counter
 from copy import deepcopy
 from io import StringIO
@@ -30,6 +31,15 @@ from astropy.io.registry.base import _UnifiedIORegistryBase
 from astropy.io.registry.compat import default_registry
 from astropy.table import Table
 
+SKIPIF_OPTIMIZED_PYTHON = pytest.mark.skipif(
+    sys.flags.optimize >= 2, reason="docstrings are not available at runtime"
+)
+ONLY_OPTIMIZED_PYTHON = pytest.mark.skipif(
+    sys.flags.optimize < 2,
+    reason="checking behavior specifically if docstrings are not present",
+)
+
+
 ###############################################################################
 # pytest setup and fixtures
 
@@ -84,7 +94,7 @@ def fmtcls2():
 
 @pytest.fixture(params=["test1", "test2"])
 def fmtcls(request):
-    yield (request.param, EmptyData)
+    return (request.param, EmptyData)
 
 
 @pytest.fixture
@@ -155,12 +165,20 @@ class TestUnifiedIORegistryBase:
         # (kw)args don't matter
         assert registry.get_formats(data_class=24) is None
 
+    @SKIPIF_OPTIMIZED_PYTHON
     def test_delay_doc_updates(self, registry, fmtcls1):
         """Test ``registry.delay_doc_updates()``."""
         # TODO! figure out what can be tested
         with registry.delay_doc_updates(EmptyData):
             registry.register_identifier(*fmtcls1, empty_identifier)
 
+    @ONLY_OPTIMIZED_PYTHON
+    def test_compat_delay_doc_updates_optimized_mode(self, registry, fmtcls1):
+        # check that the context manager doesn't raise an exception
+        # but otherwise it should be a pure no-op
+        with registry.delay_doc_updates(EmptyData):
+            pass
+
     def test_register_identifier(self, registry, fmtcls1, fmtcls2):
         """Test ``registry.register_identifier()``."""
         # initial check it's not registered
@@ -332,6 +350,7 @@ class TestUnifiedInputRegistry(TestUnifiedIORegistryBase):
         """Test ``registry.get_formats()``."""
         raise AssertionError()
 
+    @SKIPIF_OPTIMIZED_PYTHON
     def test_delay_doc_updates(self, registry, fmtcls1):
         """Test ``registry.delay_doc_updates()``."""
         super().test_delay_doc_updates(registry, fmtcls1)
@@ -353,6 +372,7 @@ class TestUnifiedInputRegistry(TestUnifiedIORegistryBase):
                     assert docs[-1][iread : iread + 3] != "Yes"
         # now test it's updated
         docs = EmptyData.read.__doc__.split("\n")
+        ihd = [i for i, s in enumerate(docs) if ("Format" in s)][0]
         ifmt = docs[ihd].index("Format") + 2
         iread = docs[ihd].index("Read") + 1
         assert docs[-2][ifmt : ifmt + 4] == "test"
@@ -700,6 +720,7 @@ class TestUnifiedOutputRegistry(TestUnifiedIORegistryBase):
 
     # ===========================================
 
+    @SKIPIF_OPTIMIZED_PYTHON
     def test_delay_doc_updates(self, registry, fmtcls1):
         """Test ``registry.delay_doc_updates()``."""
         super().test_delay_doc_updates(registry, fmtcls1)
@@ -722,6 +743,7 @@ class TestUnifiedOutputRegistry(TestUnifiedIORegistryBase):
                     assert docs[-1][iwrite : iwrite + 3] != "Yes"
         # now test it's updated
         docs = EmptyData.write.__doc__.split("\n")
+        ihd = [i for i, s in enumerate(docs) if ("Format" in s)][0]
         ifmt = docs[ihd].index("Format") + 1
         iwrite = docs[ihd].index("Write") + 2
         assert fmt in docs[-2][ifmt : ifmt + len(fmt) + 1]
@@ -1005,10 +1027,6 @@ class TestUnifiedIORegistry(TestUnifiedInputRegistry, TestUnifiedOutputRegistry)
         """Test ``registry.get_formats()``."""
         raise AssertionError()
 
-    def test_delay_doc_updates(self, registry, fmtcls1):
-        """Test ``registry.delay_doc_updates()``."""
-        super().test_delay_doc_updates(registry, fmtcls1)
-
     # -----------------------
 
     def test_identifier_origin(self, registry, fmtcls1, fmtcls2):
@@ -1095,7 +1113,7 @@ class TestSubclass:
     @pytest.fixture(autouse=True)
     def registry(self):
         """I/O registry. Not cleaned."""
-        yield
+        return
 
     def test_read_table_subclass(self):
         class MyTable(Table):
