@@ -3,18 +3,18 @@ A module that provides functions for manipulating bit masks and data quality
 (DQ) arrays.
 
 """
+
 import numbers
 import warnings
-from collections import OrderedDict
 
 import numpy as np
 
 __all__ = [
-    "bitfield_to_boolean_mask",
-    "interpret_bit_flags",
     "BitFlagNameMap",
-    "extend_bit_flag_map",
     "InvalidBitFlag",
+    "bitfield_to_boolean_mask",
+    "extend_bit_flag_map",
+    "interpret_bit_flags",
 ]
 
 
@@ -42,7 +42,7 @@ def _is_bit_flag(n):
     if n < 1:
         return False
 
-    return bin(n).count("1") == 1
+    return n.bit_count() == 1
 
 
 def _is_int(n):
@@ -54,8 +54,6 @@ def _is_int(n):
 class InvalidBitFlag(ValueError):
     """Indicates that a value is not an integer that is a power of 2."""
 
-    pass
-
 
 class BitFlag(int):
     """Bit flags: integer values that are powers of 2."""
@@ -68,8 +66,8 @@ class BitFlag(int):
 
         if not (_is_int(val) and _is_bit_flag(val)):
             raise InvalidBitFlag(
-                "Value '{}' is not a valid bit flag: bit flag value must be "
-                "an integral power of two.".format(val)
+                f"Value '{val}' is not a valid bit flag: bit flag value must be "
+                "an integral power of two."
             )
 
         s = int.__new__(cls, val)
@@ -79,7 +77,7 @@ class BitFlag(int):
 
 
 class BitFlagNameMeta(type):
-    def __new__(mcls, name, bases, members):
+    def __new__(cls, name, bases, members):
         for k, v in members.items():
             if not k.startswith("_"):
                 v = BitFlag(v)
@@ -88,7 +86,7 @@ class BitFlagNameMeta(type):
         attrl = list(map(str.lower, attr))
 
         if _ENABLE_BITFLAG_CACHING:
-            cache = OrderedDict()
+            cache = {}
 
         for b in bases:
             for k, v in b.__dict__.items():
@@ -115,7 +113,7 @@ class BitFlagNameMeta(type):
         else:
             members = {"_locked": True, "__version__": "", **members}
 
-        return super().__new__(mcls, name, bases, members)
+        return super().__new__(cls, name, bases, members)
 
     def __setattr__(cls, name, val):
         if name == "_locked":
@@ -175,7 +173,7 @@ class BitFlagNameMeta(type):
             items = dict(items)
 
         return extend_bit_flag_map(
-            cls.__name__ + "_" + "_".join([k for k in items]), cls, **items
+            cls.__name__ + "_" + "_".join(list(items)), cls, **items
         )
 
     def __iadd__(cls, other):
@@ -223,8 +221,6 @@ class BitFlagNameMap(metaclass=BitFlagNameMeta):
 
     """
 
-    pass
-
 
 def extend_bit_flag_map(cls_name, base_cls=BitFlagNameMap, **kwargs):
     """
@@ -430,6 +426,7 @@ def interpret_bit_flags(bit_flags, flip_bits=None, flag_name_map=None):
                 )
             bit_flags = [bit_flags]
 
+        bit_flags = [f.strip() for f in bit_flags]
         if flag_name_map is not None:
             try:
                 int(bit_flags[0])
