@@ -1,12 +1,14 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import warnings
-from contextlib import nullcontext
+from unittest.mock import MagicMock
 
-import matplotlib
-import matplotlib.pyplot as plt
+import matplotlib as mpl
 import numpy as np
 import pytest
+from matplotlib.backends.backend_agg import FigureCanvasAgg
 from matplotlib.contour import QuadContourSet
+from matplotlib.figure import Figure
+from numpy.testing import assert_allclose
 from packaging.version import Version
 
 from astropy import units as u
@@ -19,37 +21,32 @@ from astropy.visualization.wcsaxes.frame import (
     RectangularFrame,
     RectangularFrame1D,
 )
+from astropy.visualization.wcsaxes.ticklabels import TickLabels
 from astropy.visualization.wcsaxes.transforms import CurvedTransform
 from astropy.visualization.wcsaxes.utils import get_coord_meta
 from astropy.wcs import WCS
 from astropy.wcs.wcsapi import HighLevelWCSWrapper, SlicedLowLevelWCS
 
-ft_version = Version(matplotlib.ft2font.__freetype_version__)
+ft_version = Version(mpl.ft2font.__freetype_version__)
 FREETYPE_261 = ft_version == Version("2.6.1")
 
 # We cannot use matplotlib.checkdep_usetex() anymore, see
 # https://github.com/matplotlib/matplotlib/issues/23244
 TEX_UNAVAILABLE = True
 
-MATPLOTLIB_LT_3_7 = Version(matplotlib.__version__) < Version("3.7")
-
-
-def teardown_function(function):
-    plt.close("all")
-
 
 def test_grid_regression(ignore_matplotlibrc):
     # Regression test for a bug that meant that if the rc parameter
     # axes.grid was set to True, WCSAxes would crash upon initialization.
-    plt.rc("axes", grid=True)
-    fig = plt.figure(figsize=(3, 3))
+    mpl.rc("axes", grid=True)
+    fig = Figure(figsize=(3, 3))
     WCSAxes(fig, [0.1, 0.1, 0.8, 0.8])
 
 
 def test_format_coord_regression(ignore_matplotlibrc, tmp_path):
     # Regression test for a bug that meant that if format_coord was called by
     # Matplotlib before the axes were drawn, an error occurred.
-    fig = plt.figure(figsize=(3, 3))
+    fig = Figure(figsize=(3, 3))
     ax = WCSAxes(fig, [0.1, 0.1, 0.8, 0.8])
     fig.add_axes(ax)
     assert ax.format_coord(10, 10) == ""
@@ -84,7 +81,7 @@ COORDSYS= 'icrs    '
 
 @pytest.mark.parametrize("grid_type", ["lines", "contours"])
 def test_no_numpy_warnings(ignore_matplotlibrc, tmp_path, grid_type):
-    fig = plt.figure()
+    fig = Figure()
     ax = fig.add_subplot(1, 1, 1, projection=WCS(TARGET_HEADER))
     ax.imshow(np.zeros((100, 200)))
     ax.coords.grid(color="white", grid_type=grid_type)
@@ -113,7 +110,8 @@ def test_no_numpy_warnings(ignore_matplotlibrc, tmp_path, grid_type):
 
 def test_invalid_frame_overlay(ignore_matplotlibrc):
     # Make sure a nice error is returned if a frame doesn't exist
-    ax = plt.subplot(1, 1, 1, projection=WCS(TARGET_HEADER))
+    fig = Figure()
+    ax = fig.add_subplot(1, 1, 1, projection=WCS(TARGET_HEADER))
     with pytest.raises(ValueError, match=r"Frame banana not found"):
         ax.get_coords_overlay("banana")
 
@@ -124,7 +122,7 @@ def test_invalid_frame_overlay(ignore_matplotlibrc):
 def test_plot_coord_transform(ignore_matplotlibrc):
     twoMASS_k_header = get_pkg_data_filename("data/2MASS_k_header")
     twoMASS_k_header = fits.Header.fromtextfile(twoMASS_k_header)
-    fig = plt.figure(figsize=(6, 6))
+    fig = Figure(figsize=(6, 6))
     ax = fig.add_axes(
         [0.15, 0.15, 0.8, 0.8], projection=WCS(twoMASS_k_header), aspect="equal"
     )
@@ -139,7 +137,7 @@ def test_plot_coord_transform(ignore_matplotlibrc):
 def test_scatter_coord_transform(ignore_matplotlibrc):
     twoMASS_k_header = get_pkg_data_filename("data/2MASS_k_header")
     twoMASS_k_header = fits.Header.fromtextfile(twoMASS_k_header)
-    fig = plt.figure(figsize=(6, 6))
+    fig = Figure(figsize=(6, 6))
     ax = fig.add_axes(
         [0.15, 0.15, 0.8, 0.8], projection=WCS(twoMASS_k_header), aspect="equal"
     )
@@ -155,18 +153,19 @@ def test_set_label_properties(ignore_matplotlibrc):
     # Regression test to make sure that arguments passed to
     # set_xlabel/set_ylabel are passed to the underlying coordinate helpers
 
-    ax = plt.subplot(1, 1, 1, projection=WCS(TARGET_HEADER))
+    fig = Figure()
+    ax = fig.add_subplot(1, 1, 1, projection=WCS(TARGET_HEADER))
 
     ax.set_xlabel("Test x label", labelpad=2, color="red")
     ax.set_ylabel("Test y label", labelpad=3, color="green")
 
-    assert ax.coords[0].axislabels.get_text() == "Test x label"
-    assert ax.coords[0].axislabels.get_minpad("b") == 2
-    assert ax.coords[0].axislabels.get_color() == "red"
+    assert ax.coords[0]._axislabels.get_text() == "Test x label"
+    assert ax.coords[0]._axislabels.get_minpad("b") == 2
+    assert ax.coords[0]._axislabels.get_color() == "red"
 
-    assert ax.coords[1].axislabels.get_text() == "Test y label"
-    assert ax.coords[1].axislabels.get_minpad("l") == 3
-    assert ax.coords[1].axislabels.get_color() == "green"
+    assert ax.coords[1]._axislabels.get_text() == "Test y label"
+    assert ax.coords[1]._axislabels.get_minpad("l") == 3
+    assert ax.coords[1]._axislabels.get_color() == "green"
 
     assert ax.get_xlabel() == "Test x label"
     assert ax.get_ylabel() == "Test y label"
@@ -211,11 +210,12 @@ def test_slicing_warnings(ignore_matplotlibrc, tmp_path):
     wcs3d.wcs.cdelt = [6.25, 6.25, 23]
     wcs3d.wcs.crval = [0.0, 0.0, 1.0]
 
+    fig = Figure()
     with warnings.catch_warnings():
         # https://github.com/astropy/astropy/issues/9690
         warnings.filterwarnings("ignore", message=r".*PY_SSIZE_T_CLEAN.*")
-        plt.subplot(1, 1, 1, projection=wcs3d, slices=("x", "y", 1))
-        plt.savefig(tmp_path / "test.png")
+        fig.add_subplot(1, 1, 1, projection=wcs3d, slices=("x", "y", 1))
+        fig.savefig(tmp_path / "test.png")
 
     # Angle case
 
@@ -224,14 +224,25 @@ def test_slicing_warnings(ignore_matplotlibrc, tmp_path):
     with warnings.catch_warnings():
         # https://github.com/astropy/astropy/issues/9690
         warnings.filterwarnings("ignore", message=r".*PY_SSIZE_T_CLEAN.*")
-        plt.clf()
-        plt.subplot(1, 1, 1, projection=wcs3d, slices=("x", "y", 2))
-        plt.savefig(tmp_path / "test.png")
+        fig.clear()
+        fig.add_subplot(1, 1, 1, projection=wcs3d, slices=("x", "y", 2))
+        fig.savefig(tmp_path / "test.png")
 
 
+@pytest.fixture
+def tmp_plt_figure():
+    import matplotlib.pyplot as plt
+
+    figure = plt.figure()
+    yield figure
+    plt.close(figure)
+
+
+@pytest.mark.usefixtures("tmp_plt_figure")
 def test_plt_xlabel_ylabel(tmp_path):
     # Regression test for a bug that happened when using plt.xlabel
     # and plt.ylabel with Matplotlib 3.0
+    import matplotlib.pyplot as plt
 
     plt.subplot(projection=WCS())
     plt.xlabel("Galactic Longitude")
@@ -258,16 +269,18 @@ def test_grid_type_contours_transform(tmp_path):
         "name": ("x", "y"),
     }
 
-    fig = plt.figure()
+    fig = Figure()
     ax = WCSAxes(fig, [0.1, 0.1, 0.8, 0.8], transform=transform, coord_meta=coord_meta)
     fig.add_axes(ax)
     ax.grid(grid_type="contours")
     fig.savefig(tmp_path / "test.png")
 
 
+@pytest.mark.usefixtures("tmp_plt_figure")
 def test_plt_imshow_origin():
     # Regression test for a bug that caused origin to be set to upper when
     # plt.imshow was called.
+    import matplotlib.pyplot as plt
 
     ax = plt.subplot(projection=WCS())
     plt.imshow(np.ones((2, 2)))
@@ -278,8 +291,8 @@ def test_plt_imshow_origin():
 def test_ax_imshow_origin():
     # Regression test for a bug that caused origin to be set to upper when
     # ax.imshow was called with no origin
-
-    ax = plt.subplot(projection=WCS())
+    fig = Figure()
+    ax = fig.add_subplot(projection=WCS())
     ax.imshow(np.ones((2, 2)))
     assert ax.get_xlim() == (-0.5, 1.5)
     assert ax.get_ylim() == (-0.5, 1.5)
@@ -292,23 +305,24 @@ def test_grid_contour_large_spacing(tmp_path):
 
     filename = tmp_path / "test.png"
 
-    ax = plt.subplot(projection=WCS())
+    fig = Figure()
+    ax = fig.add_subplot(projection=WCS())
     ax.set_xlim(-0.5, 1.5)
     ax.set_ylim(-0.5, 1.5)
     ax.coords[0].set_ticks(values=[] * u.one)
 
     ax.coords[0].grid(grid_type="contours")
-    plt.savefig(filename)
+    fig.savefig(filename)
 
     ax.coords[0].grid(grid_type="contours")
-    plt.savefig(filename)
+    fig.savefig(filename)
 
 
 def test_contour_return():
     # Regression test for a bug that caused contour and contourf to return None
     # instead of the contour object.
 
-    fig = plt.figure()
+    fig = Figure()
     ax = WCSAxes(fig, [0.1, 0.1, 0.8, 0.8])
     fig.add_axes(ax)
 
@@ -323,19 +337,10 @@ def test_contour_empty():
     # Regression test for a bug that caused contour to crash if no contours
     # were present.
 
-    fig = plt.figure()
+    fig = Figure()
     ax = WCSAxes(fig, [0.1, 0.1, 0.8, 0.8])
     fig.add_axes(ax)
-
-    if MATPLOTLIB_LT_3_7:
-        ctx = pytest.warns(
-            UserWarning, match="No contour levels were found within the data range"
-        )
-    else:
-        ctx = nullcontext()
-
-    with ctx:
-        ax.contour(np.zeros((4, 4)), transform=ax.get_transform("world"))
+    ax.contour(np.zeros((4, 4)), transform=ax.get_transform("world"))
 
 
 def test_iterate_coords(ignore_matplotlibrc):
@@ -348,7 +353,8 @@ def test_iterate_coords(ignore_matplotlibrc):
     wcs3d.wcs.cdelt = [6.25, 6.25, 23]
     wcs3d.wcs.crval = [0.0, 0.0, 1.0]
 
-    ax = plt.subplot(1, 1, 1, projection=wcs3d, slices=("x", "y", 1))
+    fig = Figure()
+    ax = fig.add_subplot(1, 1, 1, projection=wcs3d, slices=("x", "y", 1))
 
     x, y, z = ax.coords
 
@@ -357,17 +363,17 @@ def test_invalid_slices_errors(ignore_matplotlibrc):
     # Make sure that users get a clear message when specifying a WCS with
     # >2 dimensions without giving the 'slices' argument, or if the 'slices'
     # argument has too many/few elements.
-
+    fig = Figure()
     wcs3d = WCS(naxis=3)
     wcs3d.wcs.ctype = ["x", "y", "z"]
 
-    plt.subplot(1, 1, 1, projection=wcs3d, slices=("x", "y", 1))
+    fig.add_subplot(1, 1, 1, projection=wcs3d, slices=("x", "y", 1))
 
     with pytest.raises(
         ValueError,
         match=r"WCS has more than 2 pixel dimensions, so 'slices' should be set",
     ):
-        plt.subplot(1, 1, 1, projection=wcs3d)
+        fig.add_subplot(1, 1, 1, projection=wcs3d)
 
     with pytest.raises(
         ValueError,
@@ -376,36 +382,36 @@ def test_invalid_slices_errors(ignore_matplotlibrc):
             r" be 3."
         ),
     ):
-        plt.subplot(1, 1, 1, projection=wcs3d, slices=("x", "y", 1, 2))
+        fig.add_subplot(1, 1, 1, projection=wcs3d, slices=("x", "y", 1, 2))
 
     wcs2d = WCS(naxis=2)
     wcs2d.wcs.ctype = ["x", "y"]
 
-    plt.clf()
-    ax = plt.subplot(1, 1, 1, projection=wcs2d)
+    fig.clear()
+    ax = fig.add_subplot(1, 1, 1, projection=wcs2d)
     assert ax.frame_class is RectangularFrame
-    plt.clf()
-    ax = plt.subplot(1, 1, 1, projection=wcs2d, slices=("x", "y"))
+    fig.clear()
+    ax = fig.add_subplot(1, 1, 1, projection=wcs2d, slices=("x", "y"))
     assert ax.frame_class is RectangularFrame
-    plt.clf()
-    ax = plt.subplot(1, 1, 1, projection=wcs2d, slices=("y", "x"))
+    fig.clear()
+    ax = fig.add_subplot(1, 1, 1, projection=wcs2d, slices=("y", "x"))
     assert ax.frame_class is RectangularFrame
-    plt.clf()
-    ax = plt.subplot(1, 1, 1, projection=wcs2d, slices=["x", "y"])
+    fig.clear()
+    ax = fig.add_subplot(1, 1, 1, projection=wcs2d, slices=["x", "y"])
     assert ax.frame_class is RectangularFrame
-    plt.clf()
-    ax = plt.subplot(1, 1, 1, projection=wcs2d, slices=(1, "x"))
+    fig.clear()
+    ax = fig.add_subplot(1, 1, 1, projection=wcs2d, slices=(1, "x"))
     assert ax.frame_class is RectangularFrame1D
 
     wcs1d = WCS(naxis=1)
     wcs1d.wcs.ctype = ["x"]
 
-    plt.clf()
-    ax = plt.subplot(1, 1, 1, projection=wcs1d)
+    fig.clear()
+    ax = fig.add_subplot(1, 1, 1, projection=wcs1d)
     assert ax.frame_class is RectangularFrame1D
 
     with pytest.raises(ValueError):
-        plt.subplot(1, 1, 1, projection=wcs2d, slices=(1, "y"))
+        fig.add_subplot(1, 1, 1, projection=wcs2d, slices=(1, "y"))
 
 
 EXPECTED_REPR_1 = """
@@ -435,19 +441,19 @@ EXPECTED_REPR_2 = """
 
 def test_repr(ignore_matplotlibrc):
     # Unit test to make sure __repr__ looks as expected
-
+    fig = Figure()
     wcs3d = WCS(GAL_HEADER)
 
     # Cube header has world coordinates as distance, lon, lat, so start off
     # by slicing in a way that we select just lon,lat:
 
-    ax = plt.subplot(1, 1, 1, projection=wcs3d, slices=(1, "x", "y"))
+    ax = fig.add_subplot(1, 1, 1, projection=wcs3d, slices=(1, "x", "y"))
     assert repr(ax.coords) == EXPECTED_REPR_1
 
     # Now slice in a way that all world coordinates are still present:
 
-    plt.clf()
-    ax = plt.subplot(1, 1, 1, projection=wcs3d, slices=("x", "y", 1))
+    fig.clear()
+    ax = fig.add_subplot(1, 1, 1, projection=wcs3d, slices=("x", "y", 1))
     assert repr(ax.coords) == EXPECTED_REPR_2
 
 
@@ -462,14 +468,14 @@ def time_spectral_wcs_2d():
 def test_time_wcs(time_spectral_wcs_2d):
     # Regression test for a bug that caused WCSAxes to error when using a WCS
     # with a time axis.
-
-    plt.subplot(projection=time_spectral_wcs_2d)
+    fig = Figure()
+    fig.add_subplot(projection=time_spectral_wcs_2d)
 
 
 @pytest.mark.skipif(TEX_UNAVAILABLE, reason="TeX is unavailable")
 def test_simplify_labels_usetex(ignore_matplotlibrc, tmp_path):
     """Regression test for https://github.com/astropy/astropy/issues/8004."""
-    plt.rc("text", usetex=True)
+    mpl.rc("text", usetex=True)
 
     header = {
         "NAXIS": 2,
@@ -487,7 +493,8 @@ def test_simplify_labels_usetex(ignore_matplotlibrc, tmp_path):
     }
 
     wcs = WCS(header)
-    fig, ax = plt.subplots(subplot_kw=dict(frame_class=EllipticalFrame, projection=wcs))
+    fig = Figure()
+    ax = fig.add_subplot(frame_class=EllipticalFrame, projection=wcs)
     ax.set_xlim(-0.5, header["NAXIS1"] - 0.5)
     ax.set_ylim(-0.5, header["NAXIS2"] - 0.5)
     ax.coords[0].set_ticklabel(exclude_overlapping=True)
@@ -499,12 +506,48 @@ def test_simplify_labels_usetex(ignore_matplotlibrc, tmp_path):
     fig.savefig(tmp_path / "plot.png")
 
 
+@pytest.mark.parametrize(
+    "usetex, unicode_minus, label_str",
+    [
+        (True, True, "$-{}$"),
+        (True, False, "$-{}$"),
+        (False, True, "\N{MINUS SIGN}{}"),
+        (False, False, "-{}"),
+    ],
+)
+def test_simplify_labels_minus_sign(
+    ignore_matplotlibrc, usetex, unicode_minus, label_str
+):
+    # Ensure minus signs aren't removed from the front of labels across a grid of configuration possibilities
+    if usetex and TEX_UNAVAILABLE:
+        pytest.skip("TeX is unavailable")
+
+    ticklabels = TickLabels(frame=MagicMock())
+    expected_labels = []
+    for i in range(1, 6):
+        label = label_str.format(i)
+        ticklabels.add(
+            axis="axis",
+            world=0,
+            angle=0,
+            text=label,
+            axis_displacement=0,
+            data=(i, i),
+        )
+        expected_labels.append(label)
+
+    with mpl.rc_context(
+        rc={"text.usetex": usetex, "axes.unicode_minus": unicode_minus}
+    ):
+        ticklabels.simplify_labels()
+    assert ticklabels.text["axis"] == expected_labels
+
+
 @pytest.mark.parametrize("frame_class", [RectangularFrame, EllipticalFrame])
 def test_set_labels_with_coords(ignore_matplotlibrc, frame_class):
     """Test if ``axis.set_xlabel()`` calls the correct ``coords[i]_set_axislabel()`` in a
     WCS plot. Regression test for https://github.com/astropy/astropy/issues/10435.
     """
-
     labels = ["RA", "Declination"]
     header = {
         "NAXIS": 2,
@@ -521,7 +564,8 @@ def test_set_labels_with_coords(ignore_matplotlibrc, frame_class):
     }
 
     wcs = WCS(header)
-    fig, ax = plt.subplots(subplot_kw=dict(frame_class=frame_class, projection=wcs))
+    fig = Figure()
+    ax = fig.add_subplot(frame_class=frame_class, projection=wcs)
     ax.set_xlabel(labels[0])
     ax.set_ylabel(labels[1])
 
@@ -536,10 +580,11 @@ def test_bbox_size(atol):
     # Test for the size of a WCSAxes bbox (only have Matplotlib >= 3.0 now)
     extents = [11.38888888888889, 3.5, 576.0, 432.0]
 
-    fig = plt.figure()
+    fig = Figure()
+    canvas = FigureCanvasAgg(fig)
     ax = WCSAxes(fig, [0.1, 0.1, 0.8, 0.8])
-    fig.add_axes(ax)
-    fig.canvas.draw()
+    canvas.figure.add_axes(ax)
+    canvas.draw()
     renderer = fig.canvas.renderer
     ax_bbox = ax.get_tightbbox(renderer)
 
@@ -552,9 +597,10 @@ def test_bbox_size(atol):
 
 
 def test_wcs_type_transform_regression():
+    fig = Figure()
     wcs = WCS(TARGET_HEADER)
     sliced_wcs = SlicedLowLevelWCS(wcs, np.s_[1:-1, 1:-1])
-    ax = plt.subplot(1, 1, 1, projection=wcs)
+    ax = fig.add_subplot(1, 1, 1, projection=wcs)
     ax.get_transform(sliced_wcs)
 
     high_wcs = HighLevelWCSWrapper(sliced_wcs)
@@ -562,7 +608,7 @@ def test_wcs_type_transform_regression():
 
 
 def test_multiple_draws_grid_contours(tmp_path):
-    fig = plt.figure()
+    fig = Figure()
     ax = fig.add_subplot(1, 1, 1, projection=WCS())
     ax.grid(color="black", grid_type="contours")
     fig.savefig(tmp_path / "plot.png")
@@ -573,9 +619,10 @@ def test_get_coord_range_nan_regression():
     # Test to make sure there is no internal casting of NaN to integers
     # NumPy 1.24 raises a RuntimeWarning if a NaN is cast to an integer
 
+    fig = Figure()
     wcs = WCS(TARGET_HEADER)
     wcs.wcs.crval[0] = 0  # Re-position the longitude wrap to the middle
-    ax = plt.subplot(1, 1, 1, projection=wcs)
+    ax = fig.add_subplot(1, 1, 1, projection=wcs)
 
     # Set the Y limits within valid latitudes/declinations
     ax.set_ylim(300, 500)
@@ -603,14 +650,14 @@ def test_get_coord_range_nan_regression():
 
 
 def test_imshow_error():
-    fig = plt.figure()
+    fig = Figure()
     ax = fig.add_subplot(1, 1, 1, projection=WCS())
     with pytest.raises(ValueError, match="Cannot use images with origin='upper"):
         ax.imshow(np.ones(100).reshape(10, 10), origin="upper")
 
 
 def test_label_setting():
-    fig = plt.figure()
+    fig = Figure()
     ax = fig.add_subplot(1, 1, 1, projection=WCS())
     # Check both xlabel and label kwargs work
     ax.set_xlabel(xlabel="label")
@@ -632,9 +679,148 @@ def test_label_setting():
 
 
 def test_invisible_bbox():
-    fig = plt.figure()
+    fig = Figure()
+    _canvas = FigureCanvasAgg(fig)
     ax = fig.add_subplot(1, 1, 1, projection=WCS())
 
     assert ax.get_tightbbox(fig.canvas.get_renderer()) is not None
     ax.set_visible(False)
     assert ax.get_tightbbox(fig.canvas.get_renderer()) is None
+
+
+def test_get_axislabel_default():
+    wcs = WCS(naxis=2)
+    wcs.wcs.ctype = "RA---TAN", "DEC--TAN"
+
+    fig = Figure()
+    _canvas = FigureCanvasAgg(fig)
+    ax = fig.add_subplot(1, 1, 1, projection=wcs)
+    assert ax.coords[0].get_axislabel() == "pos.eq.ra"
+    assert ax.coords[1].get_axislabel() == "pos.eq.dec"
+
+    # Make sure that setting axis labels explicitly works, including to an
+    # empty string
+    ax.coords[0].set_axislabel("Right Ascension")
+    ax.coords[1].set_axislabel("")
+    assert ax.coords[0].get_axislabel() == "Right Ascension"
+    assert ax.coords[1].get_axislabel() == ""
+
+
+def test_plot_coord_slicing(ignore_matplotlibrc):
+    # Regression test to ensure plot_coord does not raise a NotImplementedError
+    # after slicing coordinates (issue #10254).
+
+    cube_header = get_pkg_data_filename("data/cube_header")
+    cube_header = fits.Header.fromtextfile(cube_header)
+
+    fig = Figure(figsize=(6, 6))
+    ax = fig.add_subplot(projection=WCS(cube_header), slices=("x", "y", 0))
+
+    c = SkyCoord(52 * u.deg, 30.5 * u.deg)
+    ax.plot_coord(c, "o")
+
+
+SIMPLIFY_CASES = [
+    (["13d14m15s", "13d14m15s"], ["13d14m15s", "15s"]),
+    (["13d14m5s", "13d14m15s"], ["13d14m5s", "15s"]),
+    (
+        ["−29°25'55\"", "−29°25'54\"", "−29°25'53\"", "−29°25'52\"", "−29°25'51\""],
+        ["−29°25'55\"", '54"', '53"', '52"', '51"'],
+    ),
+    (
+        [
+            r"0$\mathregular{^h}$",
+            r"10$\mathregular{^h}$",
+            r"10$\mathregular{^h}$",
+            r"5$\mathregular{^h}$",
+        ],
+        [
+            r"0$\mathregular{^h}$",
+            r"10$\mathregular{^h}$",
+            r"10$\mathregular{^h}$",
+            r"5$\mathregular{^h}$",
+        ],
+    ),
+    (
+        [
+            r"0$\mathregular{^h}$10$\mathregular{^m}$5$\mathregular{^m}$",
+            r"0$\mathregular{^h}$10$\mathregular{^m}$10$\mathregular{^m}$",
+            r"0$\mathregular{^h}$10$\mathregular{^m}$15$\mathregular{^m}$",
+            r"0$\mathregular{^h}$10$\mathregular{^m}$15$\mathregular{^m}$",
+        ],
+        [
+            r"0$\mathregular{^h}$10$\mathregular{^m}$5$\mathregular{^m}$",
+            r"10$\mathregular{^m}$",
+            r"15$\mathregular{^m}$",
+            r"15$\mathregular{^m}$",
+        ],
+    ),
+    (
+        [
+            "$17^{\\mathrm{h}}47^{\\mathrm{m}}53.8^{\\mathrm{s}}$",
+            "$17^{\\mathrm{h}}47^{\\mathrm{m}}53.6^{\\mathrm{s}}$",
+        ],
+        [
+            "$17^{\\mathrm{h}}47^{\\mathrm{m}}53.8^{\\mathrm{s}}$",
+            "$53.6^{\\mathrm{s}}$",
+        ],
+    ),
+]
+
+
+@pytest.mark.parametrize(("before", "after"), SIMPLIFY_CASES)
+def test_simplify_cases(before, after):
+    # Regression test for a bug that caused the simplification to not work
+    # correctly in the presence of dollar signs in LaTeX strings.
+
+    ticklabels = TickLabels(frame=MagicMock())
+    expected_labels = []
+
+    for i, label in enumerate(before):
+        ticklabels.add(
+            axis="axis",
+            world=0,
+            angle=0,
+            text=label,
+            axis_displacement=i,
+            data=(i, i),
+        )
+
+    ticklabels.simplify_labels()
+    assert ticklabels.text["axis"] == after
+
+
+def test_get_transform_unit_mismatch():
+    """
+    Regression test for a bug that caused get_transform to ignore differences
+    in WCS units.
+
+    https://github.com/astropy/astropy/issues/18246
+    """
+
+    wcs_deg = WCS(naxis=2, preserve_units=True)
+    wcs_deg.wcs.ctype = "RA---TAN", "DEC--TAN"
+    wcs_deg.wcs.crval = 20, 30
+    wcs_deg.wcs.cunit = "deg", "deg"
+    wcs_deg.wcs.crpix = 1, 1
+    wcs_deg.wcs.cdelt = 1 / 60, 1 / 60
+
+    wcs_arcmin = WCS(naxis=2, preserve_units=True)
+    wcs_arcmin.wcs.ctype = "RA---TAN", "DEC--TAN"
+    wcs_arcmin.wcs.crval = 1200, 1800
+    wcs_arcmin.wcs.cunit = "arcmin", "arcmin"
+    wcs_arcmin.wcs.crpix = 1, 1
+    wcs_arcmin.wcs.cdelt = 1, 1
+
+    fig = Figure(figsize=(6, 6))
+    ax = fig.add_subplot(projection=wcs_arcmin)
+    transform1 = ax.get_transform(wcs_arcmin)
+    transform2 = ax.get_transform(wcs_deg)
+
+    # Since the two WCS are equivalent, the returned transforms should also
+    # be equivalent
+
+    rng = np.random.default_rng(12345)
+    pixels = rng.uniform(0, 100, (2, 100))
+
+    assert_allclose(transform1.transform(pixels), transform2.transform(pixels))
